# [Code of Conduct](./contributing/code-of-conduct.md)
This project has and enforces a Code of Conduct. This must be adhered to at all times when engaging with maintainers not only on Github but also all other mediums (including social networks). The maintainers reserve the right to remove you from being able to contribute or comment on this project.

---

# [Issues](../../wiki/github_issues)
When a new issue is created it will use a template that will ask for all the relevant information. If there is something missing or confusing, please look at the contributing guidelines for Issues on the wiki.

---

# [Pull Requests](../../wiki/github_prs)
On each pull request, a new CI build will be dispatched. This will run the test suite and upload the results of the coverage report. This project uses a tool called Danger to analyze many aspects of a PR and report if anything about the PR breaks expectations that the repo has. If you are interested in what will be analyzed, then please look at the contributing guildelines for PRs on the wiki.

---

You made it! If you have finished reading the contributing guide then you can put 🌈 in your issue or pull request to acknowledge that you have read this document and have done your best to adhere